@@ -10,23 +10,23 @@ module Data.Conduit.Cereal.Internal
   , mkSinkGet
   ) where
 
-import           Control.Monad (when)
+import           Control.Monad (forever, when)
 import qualified Data.ByteString as BS
 import qualified Data.Conduit as C
 import           Data.Serialize hiding (get, put)
 
 -- | What should we do if the Get fails?
-type ConduitErrorHandler m o = String -> C.GLConduit BS.ByteString m o
-type SinkErrorHandler m r = String -> C.GLSink BS.ByteString m r
+type ConduitErrorHandler m o = String -> C.Conduit BS.ByteString m o
+type SinkErrorHandler m r = String -> C.Consumer BS.ByteString m r
 
 -- | What should we do if the stream is done before the Get is done?
-type SinkTerminationHandler m r = (BS.ByteString -> Result r) -> C.GLSink BS.ByteString m r
+type SinkTerminationHandler m r = (BS.ByteString -> Result r) -> C.Consumer BS.ByteString m r
 
 -- | Construct a conduitGet with the specified 'ErrorHandler'
-mkConduitGet :: C.MonadThrow m
+mkConduitGet :: Monad m
              => ConduitErrorHandler m o
              -> Get o
-             -> C.GLConduit BS.ByteString m o
+             -> C.Conduit BS.ByteString m o
 mkConduitGet errorHandler get = consume True (runGetPartial get) [] BS.empty
   where pull f b s
           | BS.null s = C.await >>= maybe (when (not $ null b) (C.leftover $ BS.concat $ reverse b)) (pull f b)
@@ -38,7 +38,7 @@ mkConduitGet errorHandler get = consume True (runGetPartial get) [] BS.empty
           Partial p -> pull p consumed BS.empty
           Done a s' -> case initial of
                          -- this only works because the Get will either _always_ consume no input, or _never_ consume no input.
-                         True  -> sequence_ $ repeat $ C.yield a
+                         True  -> forever $ C.yield a
                          False -> C.yield a >> pull (runGetPartial get) [] s'
 --                         False -> C.yield a >> C.leftover s' >> mkConduitGet errorHandler get
           where consumed = s : b
@@ -48,7 +48,7 @@ mkSinkGet :: Monad m
           => SinkErrorHandler m r
           -> SinkTerminationHandler m r
           -> Get r
-          -> C.GLSink BS.ByteString m r
+          -> C.Consumer BS.ByteString m r
 mkSinkGet errorHandler terminationHandler get = consume (runGetPartial get) [] BS.empty
   where pull f b s
           | BS.null s = C.await >>= \ x -> case x of
